summaryrefslogtreecommitdiffstats
path: root/native/src/window
diff options
context:
space:
mode:
Diffstat (limited to 'native/src/window')
-rw-r--r--native/src/window/compositor.rs (renamed from native/src/window/backend.rs)4
1 files changed, 2 insertions, 2 deletions
diff --git a/native/src/window/backend.rs b/native/src/window/compositor.rs
index d8726fd4..ae010c89 100644
--- a/native/src/window/backend.rs
+++ b/native/src/window/compositor.rs
@@ -2,8 +2,8 @@ use crate::mouse;
use raw_window_handle::HasRawWindowHandle;
-/// A graphics backend that can render to windows.
-pub trait Backend: Sized {
+/// A graphics compositor that can draw to windows.
+pub trait Compositor: Sized {
/// The settings of the backend.
type Settings: Default + Clone;